==> alfresco-repository-16.35-sources.jar: org/alfresco/filesys/repo/ContentComparator.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.filesys.repo;

import java.io.File;
import java.io.InputStream;

import org.alfresco.service.cmr.repository.ContentReader;

public interface ContentComparator
{
    /**
     * Are the two content items equal?
     * <p>
     * For most cases a simple binary comparison is sufficient but some mimetypes 
     * trivial changes need to be discarded.
     * <p>
     * @param existingContent
     * @param file file
     * @return true content is equal, false content is different.
     */
    boolean isContentEqual(ContentReader existingContent, File file);
}

==> alfresco-repository-26.1.0.25-sources.jar: org/alfresco/filesys/repo/ContentComparator.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.filesys.repo;

import java.io.File;

import org.alfresco.service.cmr.repository.ContentReader;

public interface ContentComparator
{
    /**
     * Are the two content items equal?
     * <p>
     * For most cases a simple binary comparison is sufficient but some mimetypes trivial changes need to be discarded.
     * <p>
     * 
     * @param existingContent
     * @param file
     *            file
     * @return true content is equal, false content is different.
     */
    boolean isContentEqual(ContentReader existingContent, File file);
}
